==> redpesk-cli_3.15.0.orig.tar.gz: redpesk-cli-3.15.0/cmd/images_constants.go <==
/*
Copyright © 2021-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (

	// --------------------------------------------------------------
	// Subcommands and their subcommands ----------------------------
	// --------------------------------------------------------------

	// images command
	imagesCmdName      = "images"
	imageCmdAlias      = "img"
	imageCmdShortUsage = "Images commands group"

	// List command
	imagesListCmd           = "list"
	imagesListCmdAlias      = "ls"
	imagesListCmdShortUsage = "List the images from the redpesk infrastructure"

	imagesListCmdTypeFlag      = "type"
	imagesListCmdTypeFlagUsage = "Specify the type of images to display"

	imagesListCmdPrjFlagUsage = "[Optional] ID of the project linked to the image targeted by the command"

	imagesListCmdHeader        = "ID\t Slug\t Name\t Architecture\t Type\t Disabled"
	imagesListCmdVerboseLine0  = "ID:\t"
	imagesListCmdVerboseLine1  = "Name:\t"
	imagesListCmdVerboseLine2  = "Slug:\t"
	imagesListCmdVerboseLine3  = "Distribution:\t"
	imagesListCmdVerboseLine4  = "Version:\t"
	imagesListCmdVerboseLine5  = "Architecture:\t"
	imagesListCmdVerboseLine6  = "Security model:\t"
	imagesListCmdVerboseLine7  = "Type:\t"
	imagesListCmdVerboseLine8  = "Download URL:\t"
	imagesListCmdVerboseLine9  = "Kickstart URL:\t"
	imagesListCmdVerboseLine10 = "Kickstart name:\t"
	imagesListCmdVerboseLine11 = "Install tree URL:\t"
	imagesListCmdVerboseLine12 = "Additional repos:\t"
	imagesListCmdVerboseLine13 = "Parent project ID:\t"
	imagesListCmdVerboseLine14 = "Disabled:\t"
	imagesListCmdVerboseLine15 = "Board model:\t"
	imagesListCmdVerboseLine16 = "Creation time:\t"
	imagesListCmdVerboseLine17 = "Update time:\t"
	imagesListCmdVerboseLine18 = "Creator:\t"
	imagesListCmdVerboseLine19 = "Access token(s):\t"
	imagesListCmdVerboseLine20 = "Parent project slug:\t"

	imgDisplayVerboseLightLineNb = 16

	// Get command
	imagesGetCmd           = "get <image-ID>"
	imagesGetCmdShortUsage = "Get the properties of an image"

	// Add command
	imagesAddCmd           = "add"
	imagesAddAlias         = "a"
	imagesAddCmdShortUsage = "Create a new image"

	imagesCmdNameFlag      = "name"
	imagesCmdNameFlagAlias = "n"
	imagesCmdNameFlagUsage = "[Mandatory] Name of the image to create"

	imagesCmdAliasFlag      = "alias"
	imagesCmdAliasFlagAlias = "a"
	imagesCmdAliasFlagUsage = "[Optional] Alias for the image name (must be unique)"

	imagesCmdDistroFlag      = "distribution"
	imagesCmdDistroFlagAlias = "d"
	imagesCmdDistroFlagUsage = "[Mandatory] Distribution \"slug\""

	imagesCmdArchFlag      = "arch"
	imagesCmdArchFlagUsage = "[Mandatory] Target architecture"

	imagesCmdSecurityFlag      = "security"
	imagesCmdSecurityFlagAlias = "s"
	imagesCmdSecurityFlagDef   = "smack"
	imagesCmdSecurityFlagUsage = "[Optional] Security model of the image"

	imagesCmdKickstartURLFlag      = "ks-url"
	imagesCmdKickstartURLFlagUsage = "[Optional] URL to the repository containing the kickstart file, needed to build the image"

	imagesCmdKickstartNameFlag      = "ks-file"
	imagesCmdKickstartNameFlagAlias = "k"
	imagesCmdKickstartNameFlagUsage = "[Optional] Kickstart filename, needed to build the image"

	imagesCmdKickstartBranchFlag      = "ks-branch"
	imagesCmdKickstartBranchFlagAlias = "b"
	imagesCmdKickstartBranchFlagUsage = "[Optional] Select the branch of the git repository containing the kickstart file"

	imagesCmdKickstartPathFlag      = "ks-path"
	imagesCmdKickstartPathFlagUsage = "[Optional] Relative path to the kickstart directory in the git repository"

	imagesCmdAddRepoFlag      = "repo"
	imagesCmdAddRepoFlagAlias = "r"
	imagesCmdAddRepoFlagUsage = "[Optional] Additional rpms repository to add in image, this flag can be used several times"

	imagesCmdNoAutoRepoFlag      = "no-auto-repos"
	imagesCmdNoAutoRepoFlagUsage = "[Optional] Tell 'rp-cli' to not add automatically repositories; use it if you now what you are doing"

	imagesCmdPrjFlag        = "project"
	imagesCmdPrjFlagAlias   = "p"
	imagesCmdPrjFlagDefault = ""
	imagesCmdPrjFlagUsage   = "[Mandatory] ID of the project linked to the image, the project repo is added at the image build"

	imagesCmdForceFlag      = "force"
	imagesCmdForceFlagAlias = "f"
	imagesCmdForceFlagUsage = "[Optional] Do not run the usual check and create the image anyway"

	imagesCmdBoardModelFlag      = "model-board"
	imagesCmdBoardModelFlagAlias = "m"
	imagesCmdBoardModelFlagDef   = "generic"
	imagesCmdBoardModelFlagUsage = "[Optional] Compatible board model for this image"

	imagesAddCmdAnsLine0 = "-- Image creation requested by user --"
	imagesAddCmdAnsLine1 = "Creation of \"%s\" image...\t"
	imagesAddCmdAnsLine2 = "Checking the repositories architecture...\t"

	// Update command
	imagesUpdateCmd           = "update <image-ID>"
	imagesUpdateAlias         = "upd"
	imagesUpdateCmdShortUsage = "Update an image settings"

	imagesUpdateCmdAnsLine0 = "-- Image update requested by user --"
	imagesUpdateCmdAnsLine2 = "Update of \"%s\" image...\t"

	imageUpdateCmdResetReposFlag      = "reset-repo"
	imageUpdateCmdResetReposFlagUsage = "[Optional] Set this flag to reset the additional repositories list"

	// Delete command
	imagesDelCmd           = "delete <image-ID>"
	imagesDelAlias         = "del"
	imagesDelCmdShortUsage = "Delete an image"

	imagesDelCmdAnsLine0 = "-- Image deletion requested by user --"
	imagesDelCmdAnsLine1 = "Deletion of \"%s\" image...\t"

	// Local build command
	imageLocalBuildCmd           = "localbuild <image-ID>"
	imageLocalBuildCmdAlias      = "lclbld"
	imageLocalBuildCmdShortUsage = "Start building a redpesk image locally"
	imageLocalBuildCmdLongUsage  = `Start building a redpesk image locally.
An object "image" needs to have been created in the backend with all the rights parameters (cf. 'rp-cli images add --help').
A local kickstart file can be specified through the '--local-kickstart' flag.`

	imagesLocalBuildCmdLocalKickFlag      = "local-kickstart"
	imagesLocalBuildCmdLocalKickFlagUsage = "[Optional] Gives the path to a local kickstart file to use to build the image"

	imagesLocalBuildCmdSizeFlag      = "size"
	imagesLocalBuildCmdSizeFlagAlias = "s"
	imagesLocalBuildCmdSizeFlagUsage = "[Optional] Specify the disk device size in gigabytes"

	imagesLocalBuildCmdAnsLine0 = "\n-- Local build of an image requested by user --\n"
	imagesLocalBuildCmdAnsLine1 = "Checking that all needed parameters are set...\t"
	imagesLocalBuildCmdAnsLine2 = "Checking and preparing the directory for image build...\t"
	imagesLocalBuildCmdAnsLine3 = "\"Image build\" directory set-up: \t%s\n"
	imagesLocalBuildCmdAnsLine4 = "\nYour local kickstart file (%s) has been copied to: \t%s\n"
	imagesLocalBuildCmdAnsLine5 = "Congratulations! Your image build seems to be successful!\nImage available in: %s\n"
	imagesLocalBuildCmdAnsLine6 = "Oups... An error appeared while building your image"
	imagesLocalBuildCmdAnsLogs1 = "\nIMAGE BUILD LOGS >>>"
	imagesLocalBuildCmdAnsLogs2 = "<<< IMAGE BUILD LOGS\n"

	imgsForceImgFlag      = "force-img"
	imgsForceImgFlagAlias = "f"
	imgsForceImgFlagUsage = "[Optional] Force the ID given as command line argument to be an image ID"

	// Release command
	imageReleaseCmd           = "release <image-id>"
	imageReleaseCmdAlias      = "rls"
	imageReleaseCmdShortUsage = "Release a redpesk image in the redpesk factory"
	imageReleaseCmdLongUsage  = `Release a redpesk image in the redpesk factory.
The image needs to have at least on successful build in order to release it. If no build ID is specified, the latest image build is used.
The release can be done only for the current members or for a larger audience.
If you want to define another audience, use the '--team', '--user' or '--all-users' flags.`

	imageReleaseCmdAnsLine0 = "-- Image release requested by user --"
	imageReleaseCmdAnsLine1 = "Checking distribution validity...\t"
	imageReleaseCmdAnsLine2 = "Requesting the factory to release the image \"%s\"...\t"
	imageReleaseCmdAnsLine3 = "Waiting for the image \"%s\" to be released...\t"
	imageReleaseCmdAnsLine4 = "Modifying the audience of \"%s\" image...\t"

	imageReleaseCmdNameFlag      = "name"
	imageReleaseCmdNameFlagAlias = "n"
	imageReleaseCmdNameFlagUsage = "[Optional] Image release name"

	imageReleaseCmdDistroFlag      = "distribution"
	imageReleaseCmdDistroFlagUsage = "[Mandatory] Targeted distribution for the release"

	imageReleaseCmdVersionFlag      = "version"
	imageReleaseCmdVersionFlagAlias = "v"
	imageReleaseCmdVersionFlagUsage = "[Mandatory] Version of the release"

	imageReleaseCmdTeamFlag      = "team"
	imageReleaseCmdTeamFlagUsage = "[Optional] Team(s) to add to the release audience"

	imageReleaseCmdUserFlag      = "user"
	imageReleaseCmdUserFlagAlias = "u"
	imageReleaseCmdUserFlagUsage = "[Optional] User(s) to add to the release audience"

	imageReleaseCmdAllUsersFlag      = "all-users"
	imageReleaseCmdAllUsersFlagAlias = "a"
	imageReleaseCmdAllUsersFlagUsage = "[Optional] Set this flag to release the image for all the users of the factory"

	// Releases subcommand
	imageReleasesCmd           = "releases"
	imageReleasesCmdShortUsage = "Images releases sub-commands group"

	// List subcommand of released image
	imageListReleasedCmdShortUsage = "List the released images from the infrastructure"

	imgRelDisplayVerboseLightLineNb = 14

	imageListReleasedCmdHeader = "ID\t Slug\t Version\t Reference"

	// Get subcommand on released image
	imageGetReleasedCmdShortUsage = "Get the properties of a released image"

	imageGetReleaseCmdAudienceFlag      = "audience"
	imageGetReleaseCmdAudienceFlagAlias = "a"
	imageGetReleaseCmdAudienceFlagUsage = "[Optional] Set this flag to display the audience of the released image"

	imageGetReleasedCmdVerboseLine0 = "Reference image ID:\t"
	imageGetReleasedCmdVerboseLine1 = "Reference image slug:\t"
	imageGetReleasedCmdVerboseLine2 = "Distribution ID:\t"
	imageGetReleasedCmdVerboseLine3 = "[Audience]"
	imageGetReleasedCmdVerboseLine4 = "All Users:\t"
	imageGetReleasedCmdVerboseLine5 = "Team(s):\t"
	imageGetReleasedCmdVerboseLine6 = "User(s):\t"
	imageGetReleasedCmdVerboseLine7 = "URL:\t"
	imageGetReleasedCmdVerboseLine8 = "Read only:\t"

	// Update subcommand on released image
	imageUpdateReleasedCmdShortUsage = "Update a released image settings (info and audience)"

	imageUpdateReleaseCmdResetUsersFlag      = "reset-users"
	imageUpdateReleaseCmdResetUsersFlagUsage = "[Optional] Set this flag to reset all the users in the audience of the released image"

	imageUpdateReleaseCmdResetTeamsFlag      = "reset-teams"
	imageUpdateReleaseCmdResetTeamsFlagUsage = "[Optional] Set this flag to reset all the teams in the audience of the released image"

	imageReleaseUpdateCmdAnsLine0 = "-- Released image update requested by user --"
	imageReleaseUpdateCmdAnsLine1 = "Requesting the factory to update the image \"%s\"...\t"
	imageReleaseUpdateCmdAnsLine2 = "Modifying the audience of \"%s\" image...\t"

	// Delete subcommand on released project
	imageDeleteReleasedCmdShortUsage = "Delete a released image"

	imageDeleteReleaseCmdAnsLine0 = "-- Released image deletion requested by user --"
	imageDeleteReleaseCmdAnsLine1 = "Requesting the factory to delete the image \"%s\"...\t"

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Messages -----------------------------------------------------
	// --------------------------------------------------------------

	// Information messages
	imgCreationInfoMsg = "Asking for the creation of the image: \"%s\""
	imgUpdateInfoMsg   = "Asking for the update of the image: \"%s\""

	// Warning messages
	imgPrepareArchNotInRepoMsg = "the following repository does not contain the \"%s\" image architecture: \"%s\""

	// Error messages
	imgNameFlagNotSetShortMsg = "empty name for image during creation"
	imgNameFlagNotSetLongMsg  = "please provide a name for your image"

	imageIDNotSetMsg   = "no image ID argument in the command line"
	imageIDRequiredMsg = "An image ID is required for the wanted operation, please provide one"

	imgIdentifierNotFound = "no image has been found with the identifier \"%s\""

	imgSeveralIdentifierFound = "several \"%s\" images have been found. Please use the UUID of the image you target"

	imgBuildMissArguments1 = "one of the following element is missing in the image definition: alias, distribution, architecture or install tree URL"
	imgBuildMissArguments2 = "not enough information about kickstart: either use the \"local-kickstart\" flag or fill the kickstart URL and name in the image object"

	imgBuildNoLocalKickFileError = "the local kickstart file specified does not exists"

	imgDeleteLocalDskFileError = "a problem appeared while deleting the '.dsk' file in the local-builder: %s"

	imgPrepareArchNotExisting    = "the following architecture does not exist in factory: \"%s\""
	imgPrepareAnotherArchInRepos = "another architecture (\"%s\") has been detected in the following additional repository: \"%s\""

	imgBuildFailedMsg = "the image's build has failed or has been canceled"

	imgKsUrlDoNotMatchRegExp = "the kickstart URL from the server \"%s\" does not match the expected format: \"%s\""

	imgDistroNotFoundInPrjErr = "the distribution with ID \"%s\" has not been found in the repos of project \"%s\""

	// Debug messages
	imgCreationDebugMsg = "Asking for the creation of the image: %+v"
	imgUpdateDebugMsg   = "Asking for the update of the image: %+v"

	// --------------------------------------------------------------
	// --------------------------------------------------------------
)

==> redpesk-cli_3.18.3.orig.tar.gz: redpesk-cli-3.18.3/cmd/images_constants.go <==
/*
Copyright © 2021-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (

	// --------------------------------------------------------------
	// Subcommands and their subcommands ----------------------------
	// --------------------------------------------------------------

	// images command
	imagesCmdName      = "images"
	imageCmdAlias      = "img"
	imageCmdShortUsage = "Images commands group"

	// List command
	imagesListCmd           = "list"
	imagesListCmdAlias      = "ls"
	imagesListCmdShortUsage = "List the images from the redpesk infrastructure"

	imagesListCmdTypeFlag      = "type"
	imagesListCmdTypeFlagUsage = "Specify the type of images to display"

	imagesListCmdPrjFlagUsage = "[Optional] ID of the project linked to the image targeted by the command"

	imagesListCmdHeader        = "ID\t Slug\t Name\t Architecture\t Type\t Disabled"
	imagesListCmdVerboseLine0  = "ID:\t"
	imagesListCmdVerboseLine1  = "Name:\t"
	imagesListCmdVerboseLine2  = "Slug:\t"
	imagesListCmdVerboseLine3  = "Distribution:\t"
	imagesListCmdVerboseLine4  = "Version:\t"
	imagesListCmdVerboseLine5  = "Architecture:\t"
	imagesListCmdVerboseLine6  = "Security model:\t"
	imagesListCmdVerboseLine7  = "Type:\t"
	imagesListCmdVerboseLine8  = "Download URL:\t"
	imagesListCmdVerboseLine9  = "Kickstart URL:\t"
	imagesListCmdVerboseLine10 = "Kickstart name:\t"
	imagesListCmdVerboseLine11 = "Install tree URL:\t"
	imagesListCmdVerboseLine12 = "Additional repos:\t"
	imagesListCmdVerboseLine13 = "Parent project ID:\t"
	imagesListCmdVerboseLine14 = "Disabled:\t"
	imagesListCmdVerboseLine15 = "Board model:\t"
	imagesListCmdVerboseLine16 = "Creation time:\t"
	imagesListCmdVerboseLine17 = "Update time:\t"
	imagesListCmdVerboseLine18 = "Creator:\t"
	imagesListCmdVerboseLine19 = "Access token(s):\t"
	imagesListCmdVerboseLine20 = "Parent project slug:\t"

	imgDisplayVerboseLightLineNb = 16

	// Get command
	imagesGetCmd           = "get <image-ID>"
	imagesGetCmdShortUsage = "Get the properties of an image"

	// Add command
	imagesAddCmd           = "add"
	imagesAddAlias         = "a"
	imagesAddCmdShortUsage = "Create a new image"

	imagesCmdNameFlag      = "name"
	imagesCmdNameFlagAlias = "n"
	imagesCmdNameFlagUsage = "[Mandatory] Name of the image to create"

	imagesCmdAliasFlag      = "alias"
	imagesCmdAliasFlagAlias = "a"
	imagesCmdAliasFlagUsage = "[Optional] Alias for the image name (must be unique)"

	imagesCmdDistroFlag      = "distribution"
	imagesCmdDistroFlagAlias = "d"
	imagesCmdDistroFlagUsage = "[Mandatory] Distribution \"slug\""

	imagesCmdArchFlag      = "arch"
	imagesCmdArchFlagUsage = "[Mandatory] Target architecture"

	imagesCmdSecurityFlag      = "security"
	imagesCmdSecurityFlagAlias = "s"
	imagesCmdSecurityFlagDef   = "smack"
	imagesCmdSecurityFlagUsage = "[Optional] Security model of the image"

	imagesCmdKickstartURLFlag      = "ks-url"
	imagesCmdKickstartURLFlagUsage = "[Optional] URL to the repository containing the kickstart file, needed to build the image"

	imagesCmdKickstartNameFlag      = "ks-file"
	imagesCmdKickstartNameFlagAlias = "k"
	imagesCmdKickstartNameFlagUsage = "[Optional] Kickstart filename, needed to build the image"

	imagesCmdKickstartBranchFlag      = "ks-branch"
	imagesCmdKickstartBranchFlagAlias = "b"
	imagesCmdKickstartBranchFlagUsage = "[Optional] Select the branch of the git repository containing the kickstart file"

	imagesCmdKickstartPathFlag      = "ks-path"
	imagesCmdKickstartPathFlagUsage = "[Optional] Relative path to the kickstart directory in the git repository"

	imagesCmdAddRepoFlag      = "repo"
	imagesCmdAddRepoFlagAlias = "r"
	imagesCmdAddRepoFlagUsage = "[Optional] Additional rpms repository to add in image, this flag can be used several times"

	imagesCmdNoAutoRepoFlag      = "no-auto-repos"
	imagesCmdNoAutoRepoFlagUsage = "[Optional] Tell 'rp-cli' to not add automatically repositories; use it if you now what you are doing"

	imagesCmdPrjFlag        = "project"
	imagesCmdPrjFlagAlias   = "p"
	imagesCmdPrjFlagDefault = ""
	imagesCmdPrjFlagUsage   = "[Mandatory] ID of the project linked to the image, the project repo is added at the image build"

	imagesCmdForceFlag      = "force"
	imagesCmdForceFlagAlias = "f"
	imagesCmdForceFlagUsage = "[Optional] Do not run the usual check and create the image anyway"

	imagesCmdBoardModelFlag      = "model-board"
	imagesCmdBoardModelFlagAlias = "m"
	imagesCmdBoardModelFlagDef   = "generic"
	imagesCmdBoardModelFlagUsage = "[Optional] Compatible board model for this image"

	imagesAddCmdAnsLine0 = "-- Image creation requested by user --"
	imagesAddCmdAnsLine1 = "Creation of \"%s\" image...\t"
	imagesAddCmdAnsLine2 = "Checking the repositories architecture...\t"

	// Update command
	imagesUpdateCmd           = "update <image-ID>"
	imagesUpdateAlias         = "upd"
	imagesUpdateCmdShortUsage = "Update an image settings"

	imagesUpdateCmdAnsLine0 = "-- Image update requested by user --"
	imagesUpdateCmdAnsLine2 = "Update of \"%s\" image...\t"

	imageUpdateCmdResetReposFlag      = "reset-repo"
	imageUpdateCmdResetReposFlagUsage = "[Optional] Set this flag to reset the additional repositories list"

	// Delete command
	imagesDelCmd           = "delete <image-ID>"
	imagesDelAlias         = "del"
	imagesDelCmdShortUsage = "Delete an image"

	imagesDelCmdAnsLine0 = "-- Image deletion requested by user --"
	imagesDelCmdAnsLine1 = "Deletion of \"%s\" image...\t"

	// Local build command
	imageLocalBuildCmd           = "localbuild <image-ID>"
	imageLocalBuildCmdAlias      = "lclbld"
	imageLocalBuildCmdShortUsage = "Start building a redpesk image locally"
	imageLocalBuildCmdLongUsage  = `Start building a redpesk image locally.
An object "image" needs to have been created in the backend with all the rights parameters (cf. 'rp-cli images add --help').
A local kickstart file can be specified through the '--local-kickstart' flag.`

	imagesLocalBuildCmdLocalKickFlag      = "local-kickstart"
	imagesLocalBuildCmdLocalKickFlagUsage = "[Optional] Gives the path to a local kickstart file to use to build the image"

	imagesLocalBuildCmdSizeFlag      = "size"
	imagesLocalBuildCmdSizeFlagAlias = "s"
	imagesLocalBuildCmdSizeFlagUsage = "[Optional] Specify the disk device size in gigabytes"

	imagesLocalBuildCmdAnsLine0 = "\n-- Local build of an image requested by user --\n"
	imagesLocalBuildCmdAnsLine1 = "Checking that all needed parameters are set...\t"
	imagesLocalBuildCmdAnsLine2 = "Checking and preparing the directory for image build...\t"
	imagesLocalBuildCmdAnsLine3 = "\"Image build\" directory set-up: \t%s\n"
	imagesLocalBuildCmdAnsLine4 = "\nYour local kickstart file (%s) has been copied to: \t%s\n"
	imagesLocalBuildCmdAnsLine5 = "Congratulations! Your image build seems to be successful!\nImage available in: %s\n"
	imagesLocalBuildCmdAnsLine6 = "Oups... An error appeared while building your image"
	imagesLocalBuildCmdAnsLogs1 = "\nIMAGE BUILD LOGS >>>"
	imagesLocalBuildCmdAnsLogs2 = "<<< IMAGE BUILD LOGS\n"

	imgsForceImgFlag      = "force-img"
	imgsForceImgFlagAlias = "f"
	imgsForceImgFlagUsage = "[Optional] Force the ID given as command line argument to be an image ID"

	// Release command
	imageReleaseCmd           = "release <image-id>"
	imageReleaseCmdAlias      = "rls"
	imageReleaseCmdShortUsage = "Release a redpesk image in the redpesk factory"
	imageReleaseCmdLongUsage  = `Release a redpesk image in the redpesk factory.
The image needs to have at least on successful build in order to release it. If no build ID is specified, the latest image build is used.
The release can be done only for the current members or for a larger audience.
If you want to define another audience, use the '--team', '--user' or '--all-users' flags.`

	imageReleaseCmdAnsLine0 = "-- Image release requested by user --"
	imageReleaseCmdAnsLine1 = "Checking distribution validity...\t"
	imageReleaseCmdAnsLine2 = "Requesting the factory to release the image \"%s\"...\t"
	imageReleaseCmdAnsLine3 = "Waiting for the image \"%s\" to be released...\t"
	imageReleaseCmdAnsLine4 = "Modifying the audience of \"%s\" image...\t"

	imageReleaseCmdNameFlag      = "name"
	imageReleaseCmdNameFlagAlias = "n"
	imageReleaseCmdNameFlagUsage = "[Optional] Image release name"

	imageReleaseCmdDistroFlag      = "distribution"
	imageReleaseCmdDistroFlagUsage = "[Mandatory] Targeted distribution for the release"

	imageReleaseCmdVersionFlag      = "version"
	imageReleaseCmdVersionFlagAlias = "v"
	imageReleaseCmdVersionFlagUsage = "[Mandatory] Version of the release"

	imageReleaseCmdTeamFlag      = "team"
	imageReleaseCmdTeamFlagUsage = "[Optional] Team(s) to add to the release audience"

	imageReleaseCmdUserFlag      = "user"
	imageReleaseCmdUserFlagAlias = "u"
	imageReleaseCmdUserFlagUsage = "[Optional] User(s) to add to the release audience"

	imageReleaseCmdAllUsersFlag      = "all-users"
	imageReleaseCmdAllUsersFlagAlias = "a"
	imageReleaseCmdAllUsersFlagUsage = "[Optional] Set this flag to release the image for all the users of the factory"

	// Releases subcommand
	imageReleasesCmd           = "releases"
	imageReleasesCmdShortUsage = "Images releases sub-commands group"

	// List subcommand of released image
	imageListReleasedCmdShortUsage = "List the released images from the infrastructure"

	imgRelDisplayVerboseLightLineNb = 14

	imageListReleasedCmdHeader = "ID\t Slug\t Version\t Reference"

	// Get subcommand on released image
	imageGetReleasedCmdShortUsage = "Get the properties of a released image"

	imageGetReleaseCmdAudienceFlag      = "audience"
	imageGetReleaseCmdAudienceFlagAlias = "a"
	imageGetReleaseCmdAudienceFlagUsage = "[Optional] Set this flag to display the audience of the released image"

	imageGetReleasedCmdVerboseLine0 = "Reference image ID:\t"
	imageGetReleasedCmdVerboseLine1 = "Reference image slug:\t"
	imageGetReleasedCmdVerboseLine2 = "Distribution ID:\t"
	imageGetReleasedCmdVerboseLine3 = "[Audience]"
	imageGetReleasedCmdVerboseLine4 = "All Users:\t"
	imageGetReleasedCmdVerboseLine5 = "Team(s):\t"
	imageGetReleasedCmdVerboseLine6 = "User(s):\t"
	imageGetReleasedCmdVerboseLine7 = "URL:\t"
	imageGetReleasedCmdVerboseLine8 = "Read only:\t"

	// Update subcommand on released image
	imageUpdateReleasedCmdShortUsage = "Update a released image settings (info and audience)"

	imageUpdateReleaseCmdResetUsersFlag      = "reset-users"
	imageUpdateReleaseCmdResetUsersFlagUsage = "[Optional] Set this flag to reset all the users in the audience of the released image"

	imageUpdateReleaseCmdResetTeamsFlag      = "reset-teams"
	imageUpdateReleaseCmdResetTeamsFlagUsage = "[Optional] Set this flag to reset all the teams in the audience of the released image"

	imageReleaseUpdateCmdAnsLine0 = "-- Released image update requested by user --"
	imageReleaseUpdateCmdAnsLine1 = "Requesting the factory to update the image \"%s\"...\t"
	imageReleaseUpdateCmdAnsLine2 = "Modifying the audience of \"%s\" image...\t"

	// Delete subcommand on released project
	imageDeleteReleasedCmdShortUsage = "Delete a released image"

	imageDeleteReleaseCmdAnsLine0 = "-- Released image deletion requested by user --"
	imageDeleteReleaseCmdAnsLine1 = "Requesting the factory to delete the image \"%s\"...\t"

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Messages -----------------------------------------------------
	// --------------------------------------------------------------

	// Information messages
	imgCreationInfoMsg = "Asking for the creation of the image: \"%s\""
	imgUpdateInfoMsg   = "Asking for the update of the image: \"%s\""

	// Warning messages
	imgPrepareArchNotInRepoMsg = "the following repository does not contain the \"%s\" image architecture: \"%s\""

	// Error messages
	imgNameFlagNotSetShortMsg = "empty name for image during creation"
	imgNameFlagNotSetLongMsg  = "please provide a name for your image"

	imageIDNotSetMsg   = "no image ID argument in the command line"
	imageIDRequiredMsg = "An image ID is required for the wanted operation, please provide one"

	imgIdentifierNotFound       = "no image has been clearly identified with \"%s\", check out the previous warning messages that may give you an explanation"
	imgIdentifierNotFoundOnTryX = "the image identifier '%s' has not been found on attempt #%d (filter: '%s')"
	tooManyImgIDFoundOnTryX     = "too many image identifiers have been found on attempt #%d (filter: '%s'). Please try to use the slug/alias instead of the image name"

	imgBuildMissArguments1 = "one of the following element is missing in the image definition: alias, distribution, architecture or install tree URL"
	imgBuildMissArguments2 = "not enough information about kickstart: either use the \"local-kickstart\" flag or fill the kickstart URL and name in the image object"

	imgBuildNoLocalKickFileError = "the local kickstart file specified does not exists"

	imgDeleteLocalDskFileError = "a problem appeared while deleting the '.dsk' file in the local-builder: %s"

	imgPrepareArchNotExisting    = "the following architecture does not exist in factory: \"%s\""
	imgPrepareAnotherArchInRepos = "another architecture (\"%s\") has been detected in the following additional repository: \"%s\""

	imgBuildFailedMsg = "the image's build has failed or has been canceled"

	imgKsUrlDoNotMatchRegExp = "the kickstart URL from the server \"%s\" does not match the expected format: \"%s\""

	imgDistroNotFoundInPrjErr = "the distribution with ID \"%s\" has not been found in the repos of project \"%s\""

	// Debug messages
	imgCreationDebugMsg = "Asking for the creation of the image: %+v"
	imgUpdateDebugMsg   = "Asking for the update of the image: %+v"

	// --------------------------------------------------------------
	// --------------------------------------------------------------
)
